﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Linq.Expressions;
using System.Web;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using VeteransAffairs.Registries.Business;
using VeteransAffairs.Registries.BusinessManager;
using VeteransAffairs.Registries.BusinessManager.Utilities;
using VeteransAffairs.Registries.BusinessManager.TBI;
using VeteransAffairs.Registries.BusinessManager.MDWS; // Add 29-Oct-2010 per JH
using System.Text;
using System.Runtime.InteropServices;
using Telerik.Web.UI;

public partial class TBI_InstrumentMpaiEntry : BaseTBIInstrumentPage //System.Web.UI.Page 
{

    #region Variable Declarations

    PatientManager patientManager = new PatientManager();
    InstrumentType instrumentType = new InstrumentType();

    int _surveyTypeId = 4; // Database Id for MPAI 

    SURVEY _survey;   // the root object in the Survey set
    SURVEY_RESULT _surveyResult; // the object representing the actual data in the Survey

    #endregion

    #region Public Methods

    public TBI_InstrumentMpaiEntry()
    {
        //Manager Save Notification Event Handler
        patientManager.BOSaveSuccess += manager_BOSaveSuccess;
    }

    #endregion

    #region Protected Methods

    /// <summary>
    /// In addition to the normal actions taken in Page_Load,
    /// instantiate the MDWS Web Service (T)ransfer (O)bject.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        // confirm instrument is active - if not, a redirect will occur.
        this.CheckActiveStatus(_surveyTypeId);

        LabelInstrumentTitle.Text = GetInstrumentTitle(_surveyTypeId);

        SetQuestionLabels();

        //TBIServiceTO _tbiServiceTo;

        try
        {
            //TBIServiceTO _tbiServiceTo;
            //_tbiServiceTo = (TBIServiceTO)Session["TBIServiceTO"];
            //_tbiInstrumentManager.TbiServiceTo = _tbiServiceTo;
            _tbiInstrumentManager.TbiServiceTo = base.GetTBIServiceTo();

            LabelBreadCrumb.Text = "TBI Instruments > Instrument Associations > "
                                  + _tbiInstrumentManager.GetInstrumentByID(_surveyTypeId).Name;
        }
        catch (Exception ex)
        {
            //Redirect to message that session is ended and need to log back in from CPRS.
            Exception _tbilogerror = HandleTBIException(ex, "InstrumentMpaiEntry.aspx", "100027", "SESSIOENDED");
            Response.Redirect("Warning.aspx?err=2", false);
        }

        if (!IsPostBack)
        {
            string _ssn = string.Empty;

            //Check if the request is to start a new item 
            //a new item page request is signified when the querystring parameter id equals zero or is not present
            if (_tbiInstrumentManager.TbiServiceTo == null)
            {
                //Redirect to message that session is ended and need to log back in from CPRS.
                //Response.Redirect("Warning.aspx?err=2");
            }
            else
            {
                base.AddtoViewStateTBIServiceTo(_tbiInstrumentManager.TbiServiceTo);

                if (instrumentType.Status != null)
                {
                    _tbiInstrumentManager.TbiServiceTo.SelectedInstrumentType = instrumentType;
                }

                _ssn = _tbiInstrumentManager.TbiServiceTo.PatientSSN;

                LabelPatient.Text = _tbiInstrumentManager.TbiServiceTo.PatientName;
                LabelSSN.Text = _tbiInstrumentManager.TbiServiceTo.PatientSSN.Trim().Length == 9 ? String.Format("{0:000-00-0000}", int.Parse(_tbiInstrumentManager.TbiServiceTo.PatientSSN)) : _tbiInstrumentManager.TbiServiceTo.PatientSSN;

                Label labelUser = (Label)Master.FindControl("LabelCurrentUser");
                if (labelUser != null)
                {
                    labelUser.Text = _tbiInstrumentManager.TbiServiceTo.UserName;
                }

                if (!string.IsNullOrEmpty(_ssn))
                {
                    string patICN = patientManager.GetPatientICNBySSN(_ssn);

                    if (!string.IsNullOrEmpty(patICN))
                    {
                        ViewState["PatientICN"] = patICN;
                        RefreshSurvey(patICN);
                    }
                    else
                    {
                        throw new ArgumentException("Patient with this SSN does not exist.");
                    }

                    if (_survey != null && !_survey.isNew)
                    {
                        SetUpSurvey(_survey);
                    }
                    string referrer = string.Empty;
                    if (Request.UrlReferrer != null)
                    {
                        referrer = Request.UrlReferrer.PathAndQuery;
                    }
                    ViewState["referrer"] = referrer;
                }

                if (_survey != null)
                {
                    if (LabelNoteTypeID.Text == "")
                    {
                        if (_tbiInstrumentManager.IsInitialNoteType(_tbiInstrumentManager.TbiServiceTo.PatientICN, _surveyTypeId))
                        {
                            LabelNoteType.Text = _tbiInstrumentManager.GetMapiNoteTypeChoices()[0].CHOICE_TEXT;
                            LabelNoteTypeID.Text = _tbiInstrumentManager.GetMapiNoteTypeChoices()[0].STD_QUESTION_CHOICE_ID.ToString();
                        }
                        else
                        {
                            LabelNoteType.Text = _tbiInstrumentManager.GetMapiNoteTypeChoices()[1].CHOICE_TEXT;
                            LabelNoteTypeID.Text = _tbiInstrumentManager.GetMapiNoteTypeChoices()[1].STD_QUESTION_CHOICE_ID.ToString();
                        }
                    }
                }
            }
        }
    }

    protected override void LoadViewState(object savedState)
    {
        base.LoadViewState(savedState);
        string surveyXml = (string)ViewState["surveyXml"];
        _survey = SerializerUtil.Deserialize<SURVEY>(surveyXml);
    }

    protected override object SaveViewState()
    {
        ViewState["surveyXml"] = _survey.Serialize();
        return base.SaveViewState();
    }

    public void btnSaveSurveyDraft_Click(object sender, EventArgs e)
    {
        Int32 status = 0;

        SaveFailMessage = "Save Failed. Please press " + btnSaveSurveyDraft.Text + " button again to avoid data loss.";

        SaveCompleteSurvey(ref status);

        SetUpSurvey(_survey);
    }

    protected void btnSubmit_Click(object sender, EventArgs e)
    {
        Int32 status = 0;

        SaveFailMessage = "Save Failed. Please press " + btnSubmitSurvey.Text + " button again to avoid data loss.";

        SaveCompleteSurvey(ref status);

        if (status > 0)
        {
            Session["survey"] = _survey;
            Session["rawScore"] = hiddenRawScore.Value.ToString();
            Session["tScore"] = hiddenTScore.Value.ToString();
            Response.Redirect("InstrumentSummaryNote.aspx", false);
        }
        else
        {
            SetUpSurvey(_survey); //Follow Save Draft logic 
        }
    }

    /// <summary>
    /// Cancel button clicked.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnCancel_Click(object sender, EventArgs e)
    {
        ViewState["surveyXml"] = null;
        ViewState["PatientICN"] = null;
        ViewState["referrer"] = null;
        Session.Remove("survey");
        Response.Redirect("Instrument.aspx", false);
        //this.ClientScript.RegisterStartupScript(typeof(Page), "closePage", "<script type='text/javascript'> window.open('','_self','');window.close(); </script>");
    }

    /// <summary>
    /// Inactive timer firing.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void InActiveTimer_Tick(object sender, EventArgs e)
    {
        Int32 status = 0;
        SaveFailMessage = "Save Failed. Please press " + btnSaveSurveyDraft.Text + " button again to avoid data loss.";

        //Page.Validate();

        //if (Page.IsValid)
        //{
            SaveCompleteSurvey(ref status);
            //SetUpSurvey(_survey);
            //Response.Redirect("InstrumentMpaiEntry.aspx", false);
        //}
        //else
        //{
        //    SaveFailMessage = "Auto-Save Validation Failed. Please complete required fields in the survey and press " + btnSaveSurveyDraft.Text + " button again to avoid data loss.";
        //}
    }

    #endregion Protected Methods

    #region Private Methods

    private List<STD_QUESTION> GetAllQuestionsForSurvey()
    {
        return _tbiInstrumentManager.SelectAllQuestions(_surveyTypeId).ToList();
    }

    private void RefreshSurvey(string patientICN)
    {
        var surveys = _tbiInstrumentManager.SelectByPatientICNAndSurveyType(patientICN, _surveyTypeId, true).ToList();

        if (surveys.Count > 0)
        {
            _survey = surveys.First();
        }
        else
        {
            _survey = new SURVEY();
        }

        _survey.SetAsChangeTrackingRoot();

    }

    private void SaveCompleteSurvey(ref Int32 status)
    {
        string patientICN = String.Empty;

        status = 0;

        //Retrieve patient's ICN from the session variable
        if (ViewState["PatientICN"] != null)
        {
            patientICN = ViewState["PatientICN"].ToString();
            if (String.IsNullOrEmpty(patientICN.Trim()))
            {
                //Lost state. Redirect to message that need to log back in from CPRS.
                Response.Redirect("Warning.aspx?err=2", false);
            }
        }
        else
        {
            //Lost state. Redirect to message that need to log back in from CPRS.
            Response.Redirect("Warning.aspx?err=2");
        }

        if (_survey != null)
        {
            if (_survey.isNew)
            {
                //Ensure that a concurrent session hasn't already inserted a record for this survey
                var surveys = _tbiInstrumentManager.SelectByPatientICNAndSurveyType(patientICN, _surveyTypeId, true).ToList();

                if (surveys.Count > 0)
                {
                    //A concurrent session has already inserted a record for this survey and it is not new anymore.
                    Response.Redirect("Warning.aspx?err=9", false);
                }
                else
                {
                    _survey.SURVEY_STATUS = "inprocess";

                    _survey.SetAsInsertOnSubmit();

                    _survey.patient_ICN = patientICN;

                    _survey.STD_SURVEY_TYPE_ID = _surveyTypeId;
                    _survey.SURVEY_DATE = DateTime.Today;

                    //Save survey if it's new before adding any responses
                    SuppressSaveMessage = true;
                    _tbiInstrumentManager.Update(_survey);
                    SuppressSaveMessage = false;

                    RefreshSurvey(patientICN);
                }
            }

            SaveSurvey(ref _survey);

            _survey.SetAsUpdateOnSubmit();
            status = _tbiInstrumentManager.Update(_survey);

            (this.Master as RegistryInstrumentMaster).SetDirtyFlag(false);

            RefreshSurvey(patientICN);
            SuppressSaveMessage = false;
        }
    }

    /// <summary>
    /// Save survey.
    /// </summary>
    /// <param name="survey"></param>
    private void SaveSurvey(ref SURVEY survey)
    {
        List<STD_QUESTION> questions = GetAllQuestionsForSurvey();

        //Delete all the survey results from database if there are any.
        SURVEY surveyWithResults = _tbiInstrumentManager.GetSurveyWithAllAnswers(survey.SURVEYS_ID);
        _tbiInstrumentManager.DeleteAllSurveyResults(surveyWithResults);

        //Survey header:
        STD_QUESTION questionMinus1 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "-1");
        _surveyResult = new SURVEY_RESULT();
        try
        {
            _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(LabelNoteTypeID.Text);
        }
        catch (Exception ex2)
        {
            Exception _tbilogerror = HandleTBIException(ex2, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - LabelNoteTypeID");
        }
        survey.SURVEY_RESULTs.Add(_surveyResult);

        if (RadioButtonListPersonReporting.SelectedIndex > -1)
        {
            _surveyResult = new SURVEY_RESULT();
            try
            {
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(RadioButtonListPersonReporting.SelectedValue);
            }
            catch (Exception ex3)
            {
                Exception _tbilogerror = HandleTBIException(ex3, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - RadioButtonListPersonReporting");
            }
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (!String.IsNullOrEmpty(TextBoxPersonReportingDetail.Text.Trim()) && (RadioButtonListPersonReporting.SelectedIndex == RadioButtonListPersonReporting.Items.Count - 1))
        {
            STD_QUESTION question01 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "0-1");
            _surveyResult = new SURVEY_RESULT();
            _surveyResult.STD_QUESTION_CHOICE_ID = question01.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 0).STD_QUESTION_CHOICE_ID;
            _surveyResult.RESULT_TEXT = TextBoxPersonReportingDetail.Text.Trim();
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        //Survey questions
        if (RadioButtonListQ1.SelectedIndex > -1)
        {
            _surveyResult = new SURVEY_RESULT();
            try
            {
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(RadioButtonListQ1.SelectedValue);
            }
            catch (Exception ex4)
            {
                Exception _tbilogerror = HandleTBIException(ex4, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - RadioButtonListQ1");
            }
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (!String.IsNullOrEmpty(TextBoxC1.Text.Trim()))
        {
            STD_QUESTION questionC1 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "C1");
            _surveyResult = new SURVEY_RESULT();
            _surveyResult.STD_QUESTION_CHOICE_ID = questionC1.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 0).STD_QUESTION_CHOICE_ID;
            _surveyResult.RESULT_TEXT = TextBoxC1.Text.Trim();
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (RadioButtonListQ2.SelectedIndex > -1)
        {
            _surveyResult = new SURVEY_RESULT();
            try
            {
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(RadioButtonListQ2.SelectedValue);
            }
            catch (Exception ex5)
            {
                Exception _tbilogerror = HandleTBIException(ex5, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - RadioButtonListQ2");
            }
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (!String.IsNullOrEmpty(TextBoxC2.Text.Trim()))
        {
            STD_QUESTION questionC2 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "C2");
            _surveyResult = new SURVEY_RESULT();
            _surveyResult.STD_QUESTION_CHOICE_ID = questionC2.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 0).STD_QUESTION_CHOICE_ID;
            _surveyResult.RESULT_TEXT = TextBoxC2.Text.Trim();
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (RadioButtonListQ3.SelectedIndex > -1)
        {
            _surveyResult = new SURVEY_RESULT();
            try
            {
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(RadioButtonListQ3.SelectedValue);
            }
            catch (Exception ex6)
            {
                Exception _tbilogerror = HandleTBIException(ex6, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - RadioButtonListQ3");
            }
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (!String.IsNullOrEmpty(TextBoxC3.Text.Trim()))
        {
            STD_QUESTION questionC3 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "C3");
            _surveyResult = new SURVEY_RESULT();
            _surveyResult.STD_QUESTION_CHOICE_ID = questionC3.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 0).STD_QUESTION_CHOICE_ID;
            _surveyResult.RESULT_TEXT = TextBoxC3.Text.Trim();
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (RadioButtonListQ4.SelectedIndex > -1)
        {
            _surveyResult = new SURVEY_RESULT();
            try
            {
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(RadioButtonListQ4.SelectedValue);
            }
            catch (Exception ex7)
            {
                Exception _tbilogerror = HandleTBIException(ex7, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - RadioButtonListQ4");
            }
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (!String.IsNullOrEmpty(TextBoxC4.Text.Trim()))
        {
            STD_QUESTION questionC4 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "C4");
            _surveyResult = new SURVEY_RESULT();
            _surveyResult.STD_QUESTION_CHOICE_ID = questionC4.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 0).STD_QUESTION_CHOICE_ID;
            _surveyResult.RESULT_TEXT = TextBoxC4.Text.Trim();
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (RadioButtonListQ5.SelectedIndex > -1)
        {
            _surveyResult = new SURVEY_RESULT();
            try
            {
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(RadioButtonListQ5.SelectedValue);
            }
            catch (Exception ex8)
            {
                Exception _tbilogerror = HandleTBIException(ex8, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - RadioButtonListQ4");
            }
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (!String.IsNullOrEmpty(TextBoxC5.Text.Trim()))
        {
            STD_QUESTION questionC5 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "C5");
            _surveyResult = new SURVEY_RESULT();
            _surveyResult.STD_QUESTION_CHOICE_ID = questionC5.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 0).STD_QUESTION_CHOICE_ID;
            _surveyResult.RESULT_TEXT = TextBoxC5.Text.Trim();
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (RadioButtonListQ6.SelectedIndex > -1)
        {
            _surveyResult = new SURVEY_RESULT();
            try
            {
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(RadioButtonListQ6.SelectedValue);
            }
            catch (Exception ex9)
            {
                Exception _tbilogerror = HandleTBIException(ex9, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - RadioButtonListQ6");
                //Should never happen. Ignore error
            }
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (!String.IsNullOrEmpty(TextBoxC6.Text.Trim()))
        {
            STD_QUESTION questionC6 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "C6");
            _surveyResult = new SURVEY_RESULT();
            _surveyResult.STD_QUESTION_CHOICE_ID = questionC6.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 0).STD_QUESTION_CHOICE_ID;
            _surveyResult.RESULT_TEXT = TextBoxC6.Text.Trim();
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (RadioButtonListQ7A.SelectedIndex > -1)
        {
            _surveyResult = new SURVEY_RESULT();
            try
            {
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(RadioButtonListQ7A.SelectedValue);
            }
            catch (Exception ex10)
            {
                Exception _tbilogerror = HandleTBIException(ex10, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - RadioButtonListQ7A");
                //Should never happen. Ignore error
            }
            survey.SURVEY_RESULTs.Add(_surveyResult);

            if (!String.IsNullOrEmpty(TextBoxC7A.Text.Trim()))
            {
                STD_QUESTION questionC7A = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "C7A");
                _surveyResult = new SURVEY_RESULT();
                _surveyResult.STD_QUESTION_CHOICE_ID = questionC7A.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 0).STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = TextBoxC7A.Text.Trim();
                survey.SURVEY_RESULTs.Add(_surveyResult);
            }
        }


        if (RadioButtonListQ7B.SelectedIndex > -1)
        {
            if (RadioButtonListQ7BR.SelectedIndex > -1)
            {
                _surveyResult = new SURVEY_RESULT();
                try
                {
                    _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(RadioButtonListQ7BR.SelectedValue);
                }
                catch (Exception ex11)
                {
                    Exception _tbilogerror = HandleTBIException(ex11, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - RadioButtonListQ7BR");
                    //Should never happen. Ignore error
                }
                survey.SURVEY_RESULTs.Add(_surveyResult);
            }

            _surveyResult = new SURVEY_RESULT();
            try
            {
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(RadioButtonListQ7B.SelectedValue);
            }
            catch (Exception ex12)
            {
                Exception _tbilogerror = HandleTBIException(ex12, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - RadioButtonListQ7B");

            }
            survey.SURVEY_RESULTs.Add(_surveyResult);

            if (!String.IsNullOrEmpty(TextBoxC7B.Text.Trim()))
            {
                STD_QUESTION questionC7B = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "C7B");
                _surveyResult = new SURVEY_RESULT();
                _surveyResult.STD_QUESTION_CHOICE_ID = questionC7B.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 0).STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = TextBoxC7B.Text.Trim();
                survey.SURVEY_RESULTs.Add(_surveyResult);
            }
        }

        if (RadioButtonListQ8.SelectedIndex > -1)
        {
            _surveyResult = new SURVEY_RESULT();
            try
            {
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(RadioButtonListQ8.SelectedValue);
            }
            catch (Exception ex13)
            {
                Exception _tbilogerror = HandleTBIException(ex13, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - RadioButtonListQ8");
                //Should never happen. Ignore error
            }
            survey.SURVEY_RESULTs.Add(_surveyResult);
        }

        if (!String.IsNullOrEmpty(TextBoxC8.Text.Trim()))
        {

            try
            {
                STD_QUESTION questionC8 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "C8");
                _surveyResult = new SURVEY_RESULT();
                _surveyResult.STD_QUESTION_CHOICE_ID = questionC8.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 0).STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = TextBoxC8.Text.Trim();
            }
            catch (Exception ex14)
            {
                Exception _tbilogerror = HandleTBIException(ex14, "InstrumentMpaiEntry.aspx", "100027", "SaveSurvey() - TextBoxC8");
                //Should never happen. Ignore error
            }

            survey.SURVEY_RESULTs.Add(_surveyResult);
        }
    }// END SaveSurvey

    /// <summary>
    /// Initialize/setup controls
    /// </summary>
    /// <param name="survey"></param>
    private void SetUpSurvey(SURVEY survey)
    {
        try
        {
            foreach (var sResult in survey.SURVEY_RESULTs)
            {
                switch (sResult.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER)
                {
                    case "-1":

                        LabelNoteTypeID.Text = sResult.STD_QUESTION_CHOICE_ID.ToString();
                        LabelNoteType.Text = sResult.STD_QUESTION_CHOICE.CHOICE_TEXT;

                        break;

                    case "0":

                        if (sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            RadioButtonListPersonReporting.SelectedIndex = sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value;
                        }
                        else
                        {
                            RadioButtonListPersonReporting.SelectedIndex = -1;
                        }

                        break;

                    case "0-1":

                        TextBoxPersonReportingDetail.Text = sResult.RESULT_TEXT;

                        break;

                    case "1":

                        if (sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            RadioButtonListQ1.SelectedIndex = sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value;
                        }
                        else
                        {
                            RadioButtonListQ1.SelectedIndex = -1;
                        }

                        break;

                    case "2":

                        if (sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            RadioButtonListQ2.SelectedIndex = sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value;
                        }
                        else
                        {
                            RadioButtonListQ2.SelectedIndex = -1;
                        }

                        break;

                    case "3":

                        if (sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            RadioButtonListQ3.SelectedIndex = sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value;
                        }
                        else
                        {
                            RadioButtonListQ3.SelectedIndex = -1;
                        }

                        break;

                    case "4":

                        if (sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            RadioButtonListQ4.SelectedIndex = sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value;
                        }
                        else
                        {
                            RadioButtonListQ4.SelectedIndex = -1;
                        }

                        break;

                    case "5":

                        if (sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            RadioButtonListQ5.SelectedIndex = sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value;
                        }
                        else
                        {
                            RadioButtonListQ5.SelectedIndex = -1;
                        }
                        break;

                    case "6":

                        if (sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            RadioButtonListQ6.SelectedIndex = sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value;
                        }
                        else
                        {
                            RadioButtonListQ6.SelectedIndex = -1;
                        }
                        break;

                    case "7A":

                        if (sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            RadioButtonListQ7A.SelectedIndex = sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value;
                        }
                        else
                        {
                            RadioButtonListQ7A.SelectedIndex = -1;
                        }

                        break;

                    case "7B-R":

                        if (sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            RadioButtonListQ7BR.SelectedIndex = sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value;
                        }
                        else
                        {
                            RadioButtonListQ7BR.SelectedIndex = -1;
                        }

                        break;

                    case "7B":

                        if (sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            RadioButtonListQ7B.SelectedIndex = sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value;
                        }
                        else
                        {
                            RadioButtonListQ7B.SelectedIndex = -1;
                        }

                        break;

                    case "8":

                        if (sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            RadioButtonListQ8.SelectedIndex = sResult.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value;
                        }
                        else
                        {
                            RadioButtonListQ8.SelectedIndex = -1;
                        }

                        break;

                    case "C1":

                        TextBoxC1.Text = sResult.RESULT_TEXT;

                        break;

                    case "C2":

                        TextBoxC2.Text = sResult.RESULT_TEXT;

                        break;

                    case "C3":

                        TextBoxC3.Text = sResult.RESULT_TEXT;

                        break;

                    case "C4":

                        TextBoxC4.Text = sResult.RESULT_TEXT;

                        break;

                    case "C5":

                        TextBoxC5.Text = sResult.RESULT_TEXT;

                        break;

                    case "C6":

                        TextBoxC6.Text = sResult.RESULT_TEXT;

                        break;

                    case "C7A":

                        TextBoxC7A.Text = sResult.RESULT_TEXT;

                        break;

                    case "C7B":

                        TextBoxC7B.Text = sResult.RESULT_TEXT;

                        break;

                    case "C8":

                        TextBoxC8.Text = sResult.RESULT_TEXT;

                        break;

                }
            }
        }
        catch (Exception ex)
        {
            Exception _tbilogerror = HandleTBIException(ex, "InstrumentMpaiEntry.aspx", "100027", "SetUpSurvey()");
        }

    }// END SaveSurvey(...)

    private void SetQuestionLabels()
    {
        if (_tbiInstrumentManager != null)
        {
            NoteTypeLabel.Text = _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("-1", _surveyTypeId) + ":";
            PersonReportingLabel.Text = _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("0", _surveyTypeId) + ":";
            Q1Label.Text = "1. " + _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("1", _surveyTypeId);
            C1Label.Text = _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("C1", _surveyTypeId) + ":";
            Q2Label.Text = "2. " + _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("2", _surveyTypeId);
            C2Label.Text = _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("C2", _surveyTypeId) + ":";
            Q3Label.Text = "3. " + _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("3", _surveyTypeId);
            C3Label.Text = _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("C3", _surveyTypeId) + ":";
            Q4Label.Text = "4. " + _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("4", _surveyTypeId);
            C4Label.Text = _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("C4", _surveyTypeId) + ":";
            Q5Label.Text = "5. " + _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("5", _surveyTypeId);
            C5Label.Text = _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("C5", _surveyTypeId) + ":";
            Q6Label.Text = "6. " + _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("6", _surveyTypeId);
            C6Label.Text = _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("C6", _surveyTypeId) + ":";
            Q7ALabel.Text = "7A. " + _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("7A", _surveyTypeId);
            C7ALabel.Text = _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("C7A", _surveyTypeId) + ":";
            Q7BLabel.Text = "7B. " + _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("7B", _surveyTypeId);
            Q7BRLabel.Text = _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("7B-R", _surveyTypeId) + ":";
            C7BLabel.Text = _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("C7B", _surveyTypeId) + ":";
            Q8Label.Text = "8. " + _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("8", _surveyTypeId);
            C8Label.Text = _tbiInstrumentManager.GetQuestionbyNumberAndSurveyType("C8", _surveyTypeId) + ":";
        }
    }

    private string GetInstrumentTitle(int surveyID)
    {
        string ret = String.Empty;

        try
        {
            List<string> instrumentTitle = _tbiInstrumentManager.GetInstrumentByID(surveyID).Title;
            if (instrumentTitle.Count > 0)
            {
                foreach (string titleLine in instrumentTitle)
                {
                    if (titleLine.Contains("PhD"))
                    {
                        ret = ret + "<small>" + titleLine + "</small>" + "<br \\>";
                    }
                    else
                    {
                        ret = ret + titleLine + "<br \\>";
                    }
                }
            }

        }
        catch (Exception ex)
        {
            Exception _tbilogerror = HandleTBIException(ex, "InstrumentMpaiEntry.aspx", "100027", "GetInstrumentTitle()");
            // Ignore error
        }

        return ret;
    }

    #endregion Private Methods

    #region Auto-generated Events
    // CAUTION: Although unused their removal will trigger errors because of their absence from the web-page
    protected void RadioButtonListFatigue_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void RadioButtonListSleepDifficulty_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void RadioButtonListAnxiety_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void RadioButtonListDepression_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void RadioButtonListIrritability_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void RadioButtonListFrustration_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void CheckBoxGrenade_CheckedChanged(object sender, EventArgs e)
    {

    }
    protected void rblBlastWaveExperience_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblBlastWaveWindExperience_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblBlastOccurrences_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblEstimatedBlastDistance_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void RadioButtonListProblemsWithPain_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void cbxListProblemsWithPain_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void RadioButtonListOverallInterferenceWithLife_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void cblProblemsWithPain_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void RadioButtonListPainInterferenceWithLife_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void RadioButtonListOverallSymptomsSinceLastEval_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblExperiencedHeadInjury_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblDurationLossOfConsciousness_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void cblTypeOfBlastExposures_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void tbxYearOfRecentHeadInjury_TextChanged(object sender, EventArgs e)
    {
        //string tbxHeadInjuryYr = sender.ToString();
    }
    protected void rblHearingDifficulty_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblBullet_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblVehicular_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblFall_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblBlastWaveCausingViolentImpact_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblBlastExplosionCausingInjuries_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblLossOfConsciousness_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblDisorientationOrConfusion_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void tbxSymptoms_TextChanged(object sender, EventArgs e)
    {

    }
    protected void RadioButtonListClinicalJudgement_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void RadioButtonListFollowUpPlan_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblExperiencedNewTbi_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblFollowUpPlan_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblDurationOfDisorientationOrConfusion_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblLossOfMemory_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblOverallInterferenceWithLife_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblProblemsWithPain_SelectedIndexChanged(object sender, EventArgs e)
    {

    }
    protected void rblPainInterferenceWithLife_SelectedIndexChanged(object sender, EventArgs e)
    {

    }

    #endregion Auto-generated Events

    #region Object/Form Mapping
    /*********************************************************** 
    ** Unused code that was explored as a potential alternative
    ************************************************************/
    //private void LoadControlsFromObject()
    //{
    //    //SURVEY _survey;

    //    //PATIENT _patient;

    //    foreach (var sResult in survey.SURVEY_RESULTs)
    //    {
    //          switch (sResult.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER)
    //          {
    //              case "A":

    //                  _surveyResult.STD_QUESTION_CHOICE_ID = 4708;
    //                  _surveyResult.RESULT_TEXT = TextBoxChiefComplaint.Text;

    //                  break;

    //              case "B":

    //                  _surveyResult.STD_QUESTION_CHOICE_ID = 4710;
    //                  _surveyResult.RESULT_TEXT = TextBoxHistoryPresentIllness.Text;

    //                  break;

    //              case "1":

    //                  _surveyResult.STD_QUESTION_CHOICE_ID = System.Convert.ToInt32(RadioButtonListChangeInMaritalStatus.SelectedItem.Value);
    //                  _surveyResult.RESULT_TEXT = RadioButtonListChangeInMaritalStatus.SelectedItem.Text;

    //                  break;
    //              //Ques
    //              case "4-A":

    //                  if (rblExperiencedHeadInjury.SelectedItem.Value == "4736")
    //                  {
    //                      _surveyResult.STD_QUESTION_CHOICE_ID = 4739;
    //                      _surveyResult.RESULT_TEXT = "";
    //                  }
    //                  else
    //                  {
    //                      _surveyResult.STD_QUESTION_CHOICE_ID = System.Convert.ToInt32(ddlMonthOfRecentHeadInjury.SelectedItem.Text);
    //                      _surveyResult.RESULT_TEXT = ddlMonthOfRecentHeadInjury.SelectedItem.Text;
    //                  }
    //                  break;
    //          }

    //    }


    //}

    //    private void LoadObjectFromControls()
    //    {
    //        foreach (var sResult in _survey.SURVEY_RESULTs)
    //        {

    //            switch ( sResult.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER )
    //            {
    //                case "A":
    //        
    //                  _surveyResult.STD_QUESTION_CHOICE_ID = 4708;
    //                  _surveyResult.RESULT_TEXT = TextBoxChiefComplaint.Text;

    //                  break;

    //         case "B":
    //        _surveyResult.STD_QUESTION_CHOICE_ID = 4710;
    //        _surveyResult.RESULT_TEXT = TextBoxHistoryPresentIllness.Text;

    //        // Question "1":
    //        _surveyResult.STD_QUESTION_CHOICE_ID = System.Convert.ToInt32(RadioButtonListChangeInMaritalStatus.SelectedItem.Value);
    //        _surveyResult.RESULT_TEXT = RadioButtonListChangeInMaritalStatus.SelectedItem.Text;

    //        //Question "2"


    //        //Question "3"


    //        Case "4-A": // & "4-B"
    //        if (rblExperiencedHeadInjury.SelectedItem.Value == "4736")
    //        {
    //            _surveyResult.STD_QUESTION_CHOICE_ID = 4739;
    //            _surveyResult.RESULT_TEXT = "Not asked (due to responses to other questions)";

    //            _surveyResult.STD_QUESTION_CHOICE_ID = 4741;
    //            _surveyResult.RESULT_TEXT = "Not asked (due to responses to other questions)";
    //        }
    //        else
    //        {
    //            _surveyResult.STD_QUESTION_CHOICE_ID = System.Convert.ToInt32(ddlMonthOfRecentHeadInjury.SelectedItem.Value);
    //            _surveyResult.RESULT_TEXT = ddlMonthOfRecentHeadInjury.SelectedItem.Text;

    //             _surveyResult.STD_QUESTION_CHOICE_ID = 4740; 
    //            _surveyResult.RESULT_TEXT = tbxYearOfRecentHeadInjury.Text;
    //        }

    //        //Ques "5-A"
    //        //_surveyResult


    //               //}

    //           // }

    //    //    JH 10/12/09 - Commenting next section : Client will use SSN within the polytrauma application instead of VPID
    //    //    Patient ID
    //    //    if item is new and patient is selected then add Patient ID to polytrauma entry
    //    //    if (HiddenFieldPatientID.Value != "" && polyTraumEntry.PATIENT_ID == null)
    //    //    {
    //    //        polyTraumEntry = PolyTraumaManager.getNewPatient
    //    //            (Helpers.getIntFromString(HiddenFieldPatientID.Value),polyTraumEntry);

    //    //        polyTraumEntry.PATIENT_ID = Helpers.getIntFromString(HiddenFieldPatientID.Value);
    //    //    }




    //    //    Injury Details
    //    //    foreach (ListItem checkboxListInjury in CheckBoxListInjuryDetails.Items)
    //    //    {
    //    //        for each item in the check box list check if it is an entity in TBI_INJURY_DETAILs
    //    //        TBI_INJURY_DETAIL existingInjury = (from e in polyTraumEntry.TBI_INJURY_DETAILs
    //    //                                           where e.STD_TBIINJURYLIST_ID == Helpers.getIntFromString(checkboxListInjury.Value)
    //    //                                           select e).FirstOrDefault();

    //    //        check if the checkboxlist item was selected,  
    //    //        if (checkboxListInjury.Selected)
    //    //        {
    //    //            if the item is selected then it needs to be in TBI_INJURY_DETAILs
    //    //            if the entity exists, that signifies the item is already in TBI_INJURY_DETAILs therefore nothing needs to be done. 
    //    //            if (existingInjury == null)
    //    //            {
    //    //                TBI_INJURY_DETAIL newInjury = new TBI_INJURY_DETAIL();
    //    //                newInjury.TBI_POLYTRAUMA_ID = polyTraumEntry.TBI_POLYTRAUMA_ID;
    //    //                newInjury.STD_TBIINJURYLIST_ID = Helpers.getIntFromString(checkboxListInjury.Value);

    //    //                polyTraumEntry.TBI_INJURY_DETAILs.Add(newInjury);
    //    //            }
    //    //        }
    //    //        else
    //    //        {
    //    //            if the item is not selected, then it needs to be taken out of TBI_INJURY_DETAILs if it is in the list
    //    //            if (existingInjury != null)
    //    //            {
    //    //                existingInjury.SetAsDeleteOnSubmit();
    //    //                polyTraumEntry.TBI_INJURY_DETAILs.Remove(existingInjury);
    //    //            }
    //    //        }
    //    //    }


    //    //    Followup
    //    //    foreach (ListItem checkboxListFollowup in CheckBoxListFollowUps.Items)
    //    //    {

    //    //        for each item in the check box list check if it is an entity in TBI_FOLLOWUPs
    //    //        TBI_FOLLOWUP existingFollowup = (from e in polyTraumEntry.TBI_FOLLOWUPs
    //    //                                         where e.STD_TBIIFOLLOWUPLIST_ID == Helpers.getIntFromString(checkboxListFollowup.Value)
    //    //                                            select e).FirstOrDefault();

    //    //        check if the checkboxlist item was selected,  
    //    //        if (checkboxListFollowup.Selected)
    //    //        {
    //    //            if the item is selected then it needs to be in TBI_FOLLOWUPs
    //    //            if the entity exists, that signifies the item is already in TBI_FOLLOWUPs therefore nothing needs to be done. 
    //    //            if (existingFollowup == null)
    //    //            {
    //    //                TBI_FOLLOWUP newFollowup = new TBI_FOLLOWUP();
    //    //                newFollowup.TBI_POLYTRAUMA_ID = polyTraumEntry.TBI_POLYTRAUMA_ID;
    //    //                newFollowup.STD_TBIIFOLLOWUPLIST_ID = Helpers.getIntFromString(checkboxListFollowup.Value);

    //    //                polyTraumEntry.TBI_FOLLOWUPs.Add(newFollowup);
    //    //            }
    //    //        }
    //    //        else
    //    //        {
    //    //            if the item is not selected, then it needs to be taken out of TBI_FOLLOWUPs if it is in the list
    //    //            if (existingFollowup != null)
    //    //            {
    //    //                existingFollowup.SetAsDeleteOnSubmit();
    //    //                polyTraumEntry.TBI_FOLLOWUPs.Remove(existingFollowup);
    //    //            }
    //    //        }
    //    //    }


    //}
    //private void SetDatesRangeValidators(bool loadControlsFromObject)
    //{
    //    Load Controls From Object
    //    if (loadControlsFromObject)
    //    {
    //            RangeValidatorTextBoxDateOfDeath.MinimumValue =
    //                !string.IsNullOrEmpty(TextBoxDateOfBirth.Text) ?
    //                      TextBoxDateOfBirth.Text : DateTime.MinValue.ToShortDateString();

    //            RangeValidatorTextBoxDateOfBirth.MaximumValue =
    //                !string.IsNullOrEmpty(TextBoxDateOfDeath.Text) ?
    //                     TextBoxDateOfDeath.Text : DateTime.Now.ToShortDateString();
    //        RangeValidatorTextBoxDateOfBirth.MinimumValue = DateTime.MinValue.ToShortDateString();
    //        RangeValidatorTextBoxDateOfBirth.MaximumValue = DateTime.Now.ToShortDateString();

    //            RangeValidatorTextBoxDateOfDeath.MaximumValue = DateTime.Now.ToShortDateString();
    //        RangeValidatorTextBoxDateOfBirth.MinimumValue = DateTime.MinValue.ToShortDateString();
    //    }
    //    //Load Object From Controls 
    //    else
    //    {
    //            RangeValidatorTextBoxDateOfDeath.MinimumValue =
    //                !string.IsNullOrEmpty(TextBoxDateOfBirth.Text) ?
    //                      TextBoxDateOfBirth.Text : DateTime.MinValue.ToShortDateString();

    //            RangeValidatorTextBoxDateOfBirth.MaximumValue =
    //                !string.IsNullOrEmpty(TextBoxDateOfDeath.Text) ?
    //                     TextBoxDateOfDeath.Text : DateTime.Now.ToShortDateString();
    //        RangeValidatorTextBoxDateOfBirth.MinimumValue = DateTime.MinValue.ToShortDateString();
    //        RangeValidatorTextBoxDateOfBirth.MaximumValue = DateTime.Now.ToShortDateString();
    //    }
    //}

    //private void TransferPatientInformationToNewPolyTraumaEntry(PATIENT patientEntry)
    //{
    //    Patient ID
    //    polyTraumEntry.PATIENT = patientEntry;
    //    HiddenFieldPatientID.Value = patientEntry.PATIENT_ID.ToString();

    //    SSN
    //    polyTraumEntry.SSN = patientEntry.SSN;


    //}

    #endregion Object/Form Mapping

}