﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web.UI;
using System.Web.UI.WebControls;
using VeteransAffairs.Registries.Business;
using VeteransAffairs.Registries.BusinessManager;
using VeteransAffairs.Registries.BusinessManager.TBI;

public partial class TBI_Instruments_QUESTInstrument : BaseTBIInstrumentPage {

    #region Variable Declarations

    PatientManager patientManager = new PatientManager();
    InstrumentType instrumentType = new InstrumentType();

    protected int _surveyTypeId = 13; // Database Id for QUEST

    SURVEY _survey;   // the root object in the Survey set
    SURVEY_RESULT _surveyResult; // the object representing the actual data in the Survey

    List<STD_QUESTION> QuestionList = new List<STD_QUESTION>();

    #endregion

    /// <summary>
    /// Default Constructor
    /// </summary>
    public TBI_Instruments_QUESTInstrument() {
        //Manager Save Notification Event Handler
        patientManager.BOSaveSuccess += manager_BOSaveSuccess;
    }

    #region Protected Methods

    /// <summary>
    /// Page Load method
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e) {
        TBIServiceTO _tbiServiceTo;

        try {
            // confirm instrument is active - if not, a redirect will occur.
            this.CheckActiveStatus(_surveyTypeId);

            _tbiServiceTo = (TBIServiceTO)Session["TBIServiceTO"];
            _tbiInstrumentManager.TbiServiceTo = _tbiServiceTo;

            string instTitle = _tbiInstrumentManager.GetInstrumentByID(_surveyTypeId).Name;

            LabelBreadCrumb.Text = "TBI Instruments > Instrument Associations > " + instTitle;
            LabelInstrumentTitle.Text = instTitle;
            Page.Title = "TBI Instruments - " + instTitle;

            if (_tbiInstrumentManager.TbiServiceTo != null) {
                Label labelUser = (Label)Master.FindControl("LabelCurrentUser");
                labelUser.Text = _tbiInstrumentManager.TbiServiceTo.UserName;

                LabelPatient.Text = _tbiInstrumentManager.TbiServiceTo.PatientName;
                LabelSSN.Text = _tbiInstrumentManager.TbiServiceTo.PatientSSN;
            }
        } catch (Exception ex) {
            //Redirect to message that session is ended and need to log back in from CPRS.
            Exception _tbilogerror = HandleTBIException(ex, "QUESTInstrument.aspx", "100027", "SESSIOENDED");
            Response.Redirect("Warning.aspx?err=2", false);
        }

        if (!IsPostBack) {
            if (instrumentType.Status != null) {
                _tbiInstrumentManager.TbiServiceTo.SelectedInstrumentType = instrumentType;
            }

            string _ssn = "";
            if (_tbiInstrumentManager.TbiServiceTo != null) {
                _ssn = _tbiInstrumentManager.TbiServiceTo.PatientSSN;
            }

            if (!string.IsNullOrEmpty(_ssn)) {
                string patICN = patientManager.GetPatientICNBySSN(_ssn);

                if (!string.IsNullOrEmpty(patICN)) {
                    ViewState["PatientICN"] = patICN;
                    RefreshSurvey(patICN);
                } else {
                    throw new ArgumentException("Patient with this SSN does not exist.");
                }

                if (_survey != null && !_survey.isNew) {
                    SetUpSurvey(_survey);
                }
                string referrer = "";
                if (Request.UrlReferrer != null) {
                    referrer = Request.UrlReferrer.PathAndQuery;
                }
                ViewState["referrer"] = referrer;
            }

            //Check if the request is to start a new item 
            //a new item page request is signified when the querystring parameter id equals zero or is not present
            if (_tbiInstrumentManager.TbiServiceTo == null) {
                //Redirect to message that session is ended and need to log back in from CPRS.
                Response.Redirect("Warning.aspx?err=2");
            } else {
                LabelPatient.Text = _tbiInstrumentManager.TbiServiceTo.PatientName;
                LabelSSN.Text = _tbiInstrumentManager.TbiServiceTo.PatientSSN.Trim().Length == 9 ? String.Format("{0:000-00-0000}", int.Parse(_tbiInstrumentManager.TbiServiceTo.PatientSSN)) : _tbiInstrumentManager.TbiServiceTo.PatientSSN;
                //LabelFacility.Text = _tbiInstrumentManager.TbiServiceTo.InstitutionName;
            }
        }
        QuestionList = GetAllQuestionsForSurvey();

        // Set control values for Diagnosis Question
        ctrlDiagnosis.QuestionText = GetQuestionText("DX");
        ctrlDiagnosis.SurveyTypeCode = HiddenSurveyType.Value;

        // Set control values for Tech Dev Question
        LabelTechDev.Text = GetQuestionText("TechDev");

        LabelDate1.Text = GetQuestionText("D");

        LabelForQ1.Text = GetQuestionText("1");
        LabelFor1Comment.Text = GetQuestionText("1Comment");

        LabelForQ2.Text = GetQuestionText("2");
        LabelFor2Comment.Text = GetQuestionText("2Comment");

        LabelForQ3.Text = GetQuestionText("3");
        LabelFor3Comment.Text = GetQuestionText("3Comment");

        LabelForQ4.Text = GetQuestionText("4");
        LabelFor4Comment.Text = GetQuestionText("4Comment");

        LabelForQ5.Text = GetQuestionText("5");
        LabelFor5Comment.Text = GetQuestionText("5Comment");

        LabelForQ6.Text = GetQuestionText("6");
        LabelFor6Comment.Text = GetQuestionText("6Comment");

        LabelForQ7.Text = GetQuestionText("7");
        LabelFor7Comment.Text = GetQuestionText("7Comment");

        LabelForQ8.Text = GetQuestionText("8");
        LabelFor8Comment.Text = GetQuestionText("8Comment");

        LabelForQ9.Text = GetQuestionText("9");
        LabelFor9Comment.Text = GetQuestionText("9Comment");

        LabelForQ10.Text = GetQuestionText("10");
        LabelFor10Comment.Text = GetQuestionText("10Comment");

        LabelForQ11.Text = GetQuestionText("11");
        LabelFor11Comment.Text = GetQuestionText("11Comment");

        LabelForQ12.Text = GetQuestionText("12");
        LabelFor12Comment.Text = GetQuestionText("12Comment");

        LabelForQ13.Text = GetQuestionText("13");

        dpDate1.MaxDate = DateTime.Now;
    }

    protected override void LoadViewState(object savedState) {
        base.LoadViewState(savedState);
        string surveyXml = (string)ViewState["surveyXml"];
        _survey = SerializerUtil.Deserialize<SURVEY>(surveyXml);
    }

    protected override object SaveViewState() {
        ViewState["surveyXml"] = _survey.Serialize();
        return base.SaveViewState();
    }

    /// <summary>
    /// Returns the Question_Text of the question with the passed Question_Number field
    /// </summary>
    /// <param name="questionId"></param>
    /// <returns></returns>
    protected string GetQuestionText(string questionId) {
        foreach (STD_QUESTION ques in QuestionList) {
            if (ques.QUESTION_NUMBER.ToLower() == questionId.ToLower()) {
                return ques.QUESTION_TEXT;
            }
        }

        return "";
    }

    /// <summary>
    /// Returns the Question_Id of the question with the passed Question_Number field
    /// </summary>
    /// <param name="questionId"></param>
    /// <returns></returns>
    protected int GetQuestionId(string questionNumber) {
        foreach (STD_QUESTION ques in QuestionList) {
            if (ques.QUESTION_NUMBER.ToLower() == questionNumber.ToLower()) {
                return ques.ID;
            }
        }

        return 0;
    }

    /// <summary>
    /// Save Draft button clicked.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    public void btnSaveSurveyDraft_Click(object sender, EventArgs e) {
        Int32 status = 0;
        SaveFailMessage = "Save Failed. Please press " + btnSaveSurveyDraft.Text + " button again to avoid data loss.";
        SaveCompleteSurvey(ref status);
        SetUpSurvey(_survey);
    }

    /// <summary>
    /// Save and Prepare Note button clicked.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnSubmit_Click(object sender, EventArgs e) {
        Int32 status = 0;
        SaveFailMessage = "Save Failed. Please press " + btnSubmitSurvey.Text + " button again to avoid data loss.";
        SaveCompleteSurvey(ref status);

        if (status > 0) {
            Session["survey"] = _survey;
            Response.Redirect("InstrumentSummaryNote.aspx", false);
        } else {
            SetUpSurvey(_survey); //Follow Save Draft logic 
        }
    }

    /// <summary>
    /// Inactive timer firing.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void InActiveTimer_Tick(object sender, EventArgs e) {
        Int32 status = 0;
        SaveFailMessage = "Save Failed. Please press " + btnSaveSurveyDraft.Text + " button again to avoid data loss.";

        Page.Validate();

        if (Page.IsValid) {
            SaveCompleteSurvey(ref status);
            //SetUpSurvey(_survey);
            Response.Redirect("QUESTInstrument.aspx", false);
        } else {
            SaveFailMessage = "Auto-Save Validation Failed. Please complete required fields in the survey and press " + btnSaveSurveyDraft.Text + " button again to avoid data loss.";
        }
    }

    /// <summary>
    /// Cancel button clicked.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnCancel_Click(object sender, EventArgs e) {
        ViewState["surveyXml"] = null;
        ViewState["PatientICN"] = null;
        ViewState["referrer"] = null;
        Session.Remove("survey");
        Response.Redirect("Instrument.aspx", false);
        //this.ClientScript.RegisterStartupScript(typeof(Page), "closePage", "<script type='text/javascript'> window.open('','_self','');window.close(); </script>");
    }

    /// <summary>
    /// Call setup survey when important items are loaded.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void cblImportantItemsQ13_DataBound(object sender, EventArgs e) {
        SetUpSurvey(_survey);
    }

    #endregion

    #region Private Methods

    /// <summary>
    /// Get all questions for this survey
    /// </summary>
    /// <returns></returns>
    private List<STD_QUESTION> GetAllQuestionsForSurvey() {
        return _tbiInstrumentManager.SelectAllQuestions(_surveyTypeId).ToList();
    }

    /// <summary>
    /// Refresh Survey
    /// </summary>
    /// <param name="patientICN"></param>
    private void RefreshSurvey(string patientICN) {
        var surveys = _tbiInstrumentManager.SelectByPatientICNAndSurveyType(patientICN, _surveyTypeId, true).ToList();

        if (surveys.Count > 0) {
            _survey = surveys.First();
        } else {
            _survey = new SURVEY();
        }

        _survey.SetAsChangeTrackingRoot();
    }

    /// <summary>
    /// Save Complete Survey
    /// </summary>
    /// <param name="status"></param>
    private void SaveCompleteSurvey(ref Int32 status) {
        lblImportantItemsError.Visible = false; //rehide and do validation

        Page.Validate();
        if (Page.IsValid && getImportantInfoCount() == 3) {
            string patientICN = String.Empty;

            status = 0;

            //Retrieve patient's ICN from the session variable
            if (ViewState["PatientICN"] != null) {
                patientICN = ViewState["PatientICN"].ToString();
                if (String.IsNullOrEmpty(patientICN.Trim())) {
                    //Lost state. Redirect to message that need to log back in from CPRS.
                    Response.Redirect("Warning.aspx?err=2", false);
                }
            } else {
                //Lost state. Redirect to message that need to log back in from CPRS.
                Response.Redirect("Warning.aspx?err=2");
            }

            if (_survey != null) {
                if (_survey.isNew) {
                    //Ensure that a concurrent session hasn't already inserted a record for this survey
                    var surveys = _tbiInstrumentManager.SelectByPatientICNAndSurveyType(patientICN, _surveyTypeId, true).ToList();

                    if (surveys.Count > 0) {
                        //A concurrent session has already inserted a record for this survey and it is not new anymore.
                        Response.Redirect("Warning.aspx?err=9", false);
                    } else {
                        _survey.SURVEY_STATUS = "inprocess";

                        _survey.SetAsInsertOnSubmit();

                        _survey.patient_ICN = patientICN;

                        _survey.STD_SURVEY_TYPE_ID = _surveyTypeId;

                        // TODO: change to datepicker
                        _survey.SURVEY_DATE = DateTime.Today;

                        //Save survey if it's new before adding any responses
                        SuppressSaveMessage = true;
                        _tbiInstrumentManager.Update(_survey);
                        SuppressSaveMessage = false;

                        RefreshSurvey(patientICN);
                    }
                }

                SaveSurvey(ref _survey);

                _survey.SetAsUpdateOnSubmit();
                status = _tbiInstrumentManager.Update(_survey);

                (this.Master as RegistryInstrumentMaster).SetDirtyFlag(false);

                RefreshSurvey(patientICN);
                SuppressSaveMessage = false;
            }
        } else if (Page.IsValid && getImportantInfoCount() != 3) {
            lblImportantItemsError.Visible = true;
            lblImportantItemsError.Text = "PLEASE SELECT THE THREE ITEMS that you consider to be the most important to you.";
        } else {
            lblImportantItemsError.Visible = true;
            lblImportantItemsError.Text = "PLEASE SELECT THE THREE ITEMS that you consider to be the most important to you.";
        }
    }

    /// <summary>
    /// Save survey.
    /// </summary>
    /// <param name="survey"></param>
    private void SaveSurvey(ref SURVEY survey) {
        List<STD_QUESTION> questions = GetAllQuestionsForSurvey();

        //Delete all the survey results from database if there are any.
        SURVEY surveyWithResults = _tbiInstrumentManager.GetSurveyWithAllAnswers(survey.SURVEYS_ID);
        _tbiInstrumentManager.DeleteAllSurveyResults(surveyWithResults);

        // Question DX
        _surveyResult = new SURVEY_RESULT();

        try {
            // Add Question DX choice
            _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(ctrlDiagnosis.GetSelectedId());
            _surveyResult.RESULT_TEXT = ctrlDiagnosis.GetSelectedResultText();
            survey.SURVEY_RESULTs.Add(_surveyResult);
        } catch (Exception surveyEx) {
            Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question DX");
        }

        // Question D
        _surveyResult = new SURVEY_RESULT();

        if (dpDate1.SelectedDate != null) {
            STD_QUESTION questionD = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "D");
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question DTE choice
                _surveyResult.STD_QUESTION_CHOICE_ID = questionD.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = ((DateTime)dpDate1.SelectedDate).ToShortDateString();
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question D");
            }
        }

        // Question TechDev
        if (!String.IsNullOrEmpty(txtTechDev.Text)) {
            STD_QUESTION questionTechDev = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "TechDev");
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question TechDev choice
                _surveyResult.STD_QUESTION_CHOICE_ID = questionTechDev.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtTechDev.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - QuestionTechDev");
            }
        }

        // Question 1
        if (rblQ1.SelectedIndex > -1) {
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question 1 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(rblQ1.SelectedValue);
                _surveyResult.RESULT_TEXT = rblQ1.SelectedItem.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question1");
            }
        }

        // Question 1 Comment
        if (!String.IsNullOrEmpty(txtComments1.Text)) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question1Comment = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "1Comment");

            try {
                // Add Question 1Comment choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question1Comment.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtComments1.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question1Comment");
            }
        }

        // Question 2
        if (rblQ2.SelectedIndex > -1) {
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question 2 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(rblQ2.SelectedValue);
                _surveyResult.RESULT_TEXT = rblQ2.SelectedItem.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question2");
            }
        }

        // Question 2 Comment
        if (!String.IsNullOrEmpty(txtComments2.Text)) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question2Comment = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "2Comment");

            try {
                // Add Question 2Comment choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question2Comment.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtComments2.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question2Comment");
            }
        }

        // Question 3
        if (rblQ3.SelectedIndex > -1) {
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question 3 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(rblQ3.SelectedValue);
                _surveyResult.RESULT_TEXT = rblQ3.SelectedItem.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question3");
            }
        }

        // Question 3 Comment
        if (!String.IsNullOrEmpty(txtComments3.Text)) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question3Comment = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "3Comment");

            try {
                // Add Question 3Comment choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question3Comment.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtComments3.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question3Comment");
            }
        }

        // Question 4
        if (rblQ4.SelectedIndex > -1) {
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question 4 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(rblQ4.SelectedValue);
                _surveyResult.RESULT_TEXT = rblQ4.SelectedItem.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question4");
            }
        }

        // Question 4 Comment
        if (!String.IsNullOrEmpty(txtComments4.Text)) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question4Comment = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "4Comment");

            try {
                // Add Question 4Comment choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question4Comment.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtComments4.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question4Comment");
            }
        }

        // Question 5
        if (rblQ5.SelectedIndex > -1) {
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question 5 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(rblQ5.SelectedValue);
                _surveyResult.RESULT_TEXT = rblQ5.SelectedItem.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question5");
            }
        }

        // Question 5 Comment
        if (!String.IsNullOrEmpty(txtComments5.Text)) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question5Comment = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "5Comment");

            try {
                // Add Question 5Comment choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question5Comment.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtComments5.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question5Comment");
            }
        }

        // Question 6
        if (rblQ6.SelectedIndex > -1) {
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question 6 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(rblQ6.SelectedValue);
                _surveyResult.RESULT_TEXT = rblQ6.SelectedItem.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question6");
            }
        }

        // Question 6 Comment
        if (!String.IsNullOrEmpty(txtComments6.Text)) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question6Comment = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "6Comment");

            try {
                // Add Question 6Comment choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question6Comment.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtComments6.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question6Comment");
            }
        }

        // Question 7
        if (rblQ7.SelectedIndex > -1) {
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question 7 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(rblQ7.SelectedValue);
                _surveyResult.RESULT_TEXT = rblQ7.SelectedItem.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question7");
            }
        }

        // Question 7 Comment
        if (!String.IsNullOrEmpty(txtComments7.Text)) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question7Comment = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "7Comment");

            try {
                // Add Question 7Comment choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question7Comment.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtComments7.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question7Comment");
            }
        }

        // Question 8
        if (rblQ8.SelectedIndex > -1) {
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question 8 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(rblQ8.SelectedValue);
                _surveyResult.RESULT_TEXT = rblQ8.SelectedItem.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question8");
            }
        }

        // Question 8 Comment
        if (!String.IsNullOrEmpty(txtComments8.Text)) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question8Comment = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "8Comment");

            try {
                // Add Question 8Comment choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question8Comment.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtComments8.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question8Comment");
            }
        }

        // Question 9
        if (rblQ9.SelectedIndex > -1) {
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question 9 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(rblQ9.SelectedValue);
                _surveyResult.RESULT_TEXT = rblQ9.SelectedItem.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question9");
            }
        }

        // Question 9 Comment
        if (!String.IsNullOrEmpty(txtComments9.Text)) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question9Comment = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "9Comment");

            try {
                // Add Question 9Comment choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question9Comment.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtComments9.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question9Comment");
            }
        }

        // Question 10
        if (rblQ10.SelectedIndex > -1) {
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question 10 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(rblQ10.SelectedValue);
                _surveyResult.RESULT_TEXT = rblQ10.SelectedItem.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question10");
            }
        }

        // Question 10 Comment
        if (!String.IsNullOrEmpty(txtComments10.Text)) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question10Comment = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "10Comment");

            try {
                // Add Question 10Comment choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question10Comment.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtComments10.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question10Comment");
            }
        }

        // Question 11
        if (rblQ11.SelectedIndex > -1) {
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question 11 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(rblQ11.SelectedValue);
                _surveyResult.RESULT_TEXT = rblQ11.SelectedItem.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question110");
            }
        }

        // Question 11 Comment
        if (!String.IsNullOrEmpty(txtComments11.Text)) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question11Comment = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "11Comment");

            try {
                // Add Question 111Comment choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question11Comment.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtComments11.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question11Comment");
            }
        }

        // Question 12
        if (rblQ12.SelectedIndex > -1) {
            _surveyResult = new SURVEY_RESULT();

            try {
                // Add Question 12 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = Convert.ToInt32(rblQ12.SelectedValue);
                _surveyResult.RESULT_TEXT = rblQ12.SelectedItem.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question1210");
            }
        }

        // Question 12 Comment
        if (!String.IsNullOrEmpty(txtComments12.Text)) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question12Comment = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "12Comment");

            try {
                // Add Question 12Comment choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question12Comment.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = txtComments12.Text;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question12Comment");
            }
        }

        // Question 13
        if (getImportantInfoCount() > 0) {
            _surveyResult = new SURVEY_RESULT();
            STD_QUESTION question13 = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "13");

            try {
                string choiceStr = "";

                foreach (ListItem li in cblImportantItemsQ13.Items) {
                    if (li.Selected) {
                        choiceStr += li.Text + ",";
                    }
                }

                if (!String.IsNullOrEmpty(choiceStr)) {
                    choiceStr = choiceStr.Substring(0, choiceStr.LastIndexOf(","));
                }

                // Add Question 13 choice
                _surveyResult.STD_QUESTION_CHOICE_ID = question13.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
                _surveyResult.RESULT_TEXT = choiceStr;
                survey.SURVEY_RESULTs.Add(_surveyResult);
            } catch (Exception surveyEx) {
                Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question13");
            }
        }

        // Question 14 - always 0 - required
        _surveyResult = new SURVEY_RESULT();
        STD_QUESTION question14 = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "14");

        try {
            // Add Question 14 choice
            _surveyResult.STD_QUESTION_CHOICE_ID = question14.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
            _surveyResult.RESULT_TEXT = "0";
            survey.SURVEY_RESULTs.Add(_surveyResult);
        } catch (Exception surveyEx) {
            Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question14");
        }

        // Question 15 - Device subscale score
        _surveyResult = new SURVEY_RESULT();
        STD_QUESTION question15 = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "15");
        decimal deviceSubscaleScore = calculateDeviceSubscaleScore();

        try {
            // Add Question 15 choice
            _surveyResult.STD_QUESTION_CHOICE_ID = question15.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
            _surveyResult.RESULT_TEXT = deviceSubscaleScore.ToString();
            survey.SURVEY_RESULTs.Add(_surveyResult);
        } catch (Exception surveyEx) {
            Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question15");
        }

        // Question 16 - Services subscale score
        _surveyResult = new SURVEY_RESULT();
        STD_QUESTION question16 = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "16");
        decimal servicesSubscaleScore = calculateServicesSubscaleScore();

        try {
            // Add Question 16 choice
            _surveyResult.STD_QUESTION_CHOICE_ID = question16.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
            _surveyResult.RESULT_TEXT = servicesSubscaleScore.ToString();
            survey.SURVEY_RESULTs.Add(_surveyResult);
        } catch (Exception surveyEx) {
            Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question16");
        }

        // Question 17 - Total QUEST score
        _surveyResult = new SURVEY_RESULT();
        STD_QUESTION question17 = questions.FirstOrDefault(Q => Q.QUESTION_NUMBER == "17");
        decimal totalSubscaleScore = calculateTotalQUESTScore();

        try {
            // Add Question 17 choice
            _surveyResult.STD_QUESTION_CHOICE_ID = question17.STD_QUESTION_CHOICEs.FirstOrDefault().STD_QUESTION_CHOICE_ID;
            _surveyResult.RESULT_TEXT = totalSubscaleScore.ToString();
            survey.SURVEY_RESULTs.Add(_surveyResult);
        } catch (Exception surveyEx) {
            Exception _tbilogerror = HandleTBIException(surveyEx, "QUESTInstrument.aspx", "100027", "SaveSurvey() - Question17");
        }

    }// END SaveSurvey

    /// <summary>
    /// Initialize/setup controls
    /// </summary>
    /// <param name="survey"></param>
    private void SetUpSurvey(SURVEY survey) {
        try {
            foreach (var sResult in survey.SURVEY_RESULTs) {
                switch (sResult.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER) {
                    case "DX":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            ctrlDiagnosis.SelectedChoiceId = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();

                            if (sResult.STD_QUESTION_CHOICE.CHOICE_TEXT.ToLower().Contains("other")) {
                                ctrlDiagnosis.SetOtherDescriptionText(sResult.RESULT_TEXT);
                            }
                        } else {
                            ctrlDiagnosis.SelectedChoiceId = null;
                        }
                        break;
                    case "D":
                        if (!String.IsNullOrEmpty(sResult.RESULT_TEXT)) {
                            DateTime temp;
                            if (DateTime.TryParse(sResult.RESULT_TEXT, out temp)) {
                                dpDate1.SelectedDate = temp;
                            }
                        }

                        break;
                    case "TechDev":
                        if (sResult.RESULT_TEXT != null) {
                            txtTechDev.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "1":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            rblQ1.SelectedValue = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();
                        } else {
                            rblQ1.SelectedIndex = -1;
                        }

                        break;
                    case "1Comment":
                        if (sResult.RESULT_TEXT != null) {
                            txtComments1.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "2":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            rblQ2.SelectedValue = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();
                        } else {
                            rblQ2.SelectedIndex = -1;
                        }

                        break;
                    case "2Comment":
                        if (sResult.RESULT_TEXT != null) {
                            txtComments2.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "3":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            rblQ3.SelectedValue = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();
                        } else {
                            rblQ3.SelectedIndex = -1;
                        }

                        break;
                    case "3Comment":
                        if (sResult.RESULT_TEXT != null) {
                            txtComments3.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "4":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            rblQ4.SelectedValue = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();
                        } else {
                            rblQ4.SelectedIndex = -1;
                        }

                        break;
                    case "4Comment":
                        if (sResult.RESULT_TEXT != null) {
                            txtComments4.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "5":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            rblQ5.SelectedValue = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();
                        } else {
                            rblQ5.SelectedIndex = -1;
                        }

                        break;
                    case "5Comment":
                        if (sResult.RESULT_TEXT != null) {
                            txtComments5.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "6":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            rblQ6.SelectedValue = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();
                        } else {
                            rblQ6.SelectedIndex = -1;
                        }

                        break;
                    case "6Comment":
                        if (sResult.RESULT_TEXT != null) {
                            txtComments6.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "7":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            rblQ7.SelectedValue = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();
                        } else {
                            rblQ7.SelectedIndex = -1;
                        }

                        break;
                    case "7Comment":
                        if (sResult.RESULT_TEXT != null) {
                            txtComments7.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "8":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            rblQ8.SelectedValue = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();
                        } else {
                            rblQ8.SelectedIndex = -1;
                        }

                        break;
                    case "8Comment":
                        if (sResult.RESULT_TEXT != null) {
                            txtComments8.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "9":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            rblQ9.SelectedValue = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();
                        } else {
                            rblQ9.SelectedIndex = -1;
                        }

                        break;
                    case "9Comment":
                        if (sResult.RESULT_TEXT != null) {
                            txtComments9.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "10":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            rblQ10.SelectedValue = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();
                        } else {
                            rblQ10.SelectedIndex = -1;
                        }

                        break;
                    case "10Comment":
                        if (sResult.RESULT_TEXT != null) {
                            txtComments10.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "11":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            rblQ11.SelectedValue = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();
                        } else {
                            rblQ11.SelectedIndex = -1;
                        }

                        break;
                    case "11Comment":
                        if (sResult.RESULT_TEXT != null) {
                            txtComments11.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "12":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            rblQ12.SelectedValue = sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID.ToString();
                        } else {
                            rblQ12.SelectedIndex = -1;
                        }

                        break;
                    case "12Comment":
                        if (sResult.RESULT_TEXT != null) {
                            txtComments12.Text = sResult.RESULT_TEXT.ToString();
                        }

                        break;
                    case "13":
                        if (sResult.STD_QUESTION_CHOICE.STD_QUESTION_CHOICE_ID > -1) {
                            // get result text ... split into array
                            string[] importantItemArray = sResult.RESULT_TEXT.Split(',');

                            foreach (string s in importantItemArray) {
                                foreach (ListItem li in cblImportantItemsQ13.Items) {
                                    if (s.ToLower() == li.Text.ToLower()) {
                                        li.Selected = true;
                                        break;
                                    }
                                }
                            }
                        }

                        break;
                    default:
                        break;
                }
            }
        } catch (Exception ex) {
            Exception _tbilogerror = HandleTBIException(ex, "DisabiltyRatingScale.aspx", "100027", "SetUpSurvey()");
        }
    }// END SetUpSurvey

    /// <summary>
    /// Retrieve instrument title
    /// </summary>
    /// <param name="surveyID"></param>
    /// <returns></returns>
    private string GetInstrumentTitle(int surveyID) {
        string ret = String.Empty;

        try {
            List<string> instrumentTitle = _tbiInstrumentManager.GetInstrumentByID(surveyID).Title;
            if (instrumentTitle.Count > 0) {
                foreach (string titleLine in instrumentTitle) {
                    if (titleLine.Contains("PhD")) {
                        ret = ret + "<small>" + titleLine + "</small>" + "<br \\>";
                    } else {
                        ret = ret + titleLine + "<br \\>";
                    }
                }
            }

        } catch (Exception ex) {
            Exception _tbilogerror = HandleTBIException(ex, "DisabiltyRatingScale.aspx", "100027", "GetInstrumentTitle()");
            // Ignore error
        }

        return ret;
    }

    /// <summary>
    /// Retrieves count of selected items in cblImportantItemsQ13
    /// </summary>
    /// <returns></returns>
    private int getImportantInfoCount() {
        int selectedItems = 0;

        foreach (ListItem li in cblImportantItemsQ13.Items) {
            if (li.Selected) {
                selectedItems++;
            }
        }

        return selectedItems;
    }

    /// <summary>
    /// For items 1 to 8, add the ratings of the valid responses and divide this sum by the number of valid items in this scale
    /// </summary>
    /// <returns></returns>
    private decimal calculateDeviceSubscaleScore() {
        decimal subScaleScore = 0;

        try {
            // look at rbl value field (convert to int)
            int q1 = Convert.ToInt32(rblQ1.SelectedItem.Text);
            int q2 = Convert.ToInt32(rblQ2.SelectedItem.Text);
            int q3 = Convert.ToInt32(rblQ3.SelectedItem.Text);
            int q4 = Convert.ToInt32(rblQ4.SelectedItem.Text);
            int q5 = Convert.ToInt32(rblQ5.SelectedItem.Text);
            int q6 = Convert.ToInt32(rblQ6.SelectedItem.Text);
            int q7 = Convert.ToInt32(rblQ7.SelectedItem.Text);
            int q8 = Convert.ToInt32(rblQ8.SelectedItem.Text);

            subScaleScore = (Convert.ToDecimal(q1 + q2 + q3 + q4 + q5 + q6 + q7 + q8) / Convert.ToDecimal(8));
            subScaleScore = Math.Round(subScaleScore, 2);

        } catch (Exception ex) {
            Exception _tbilogerror = HandleTBIException(ex, "QUESTInstrument.aspx", "100027", "calculateDeviceSubscaleScore()");
        }

        return subScaleScore;
    }

    /// <summary>
    /// For items 9 to 12, add the ratings of the valid responses and divide this sum by the number of valid items in this scale.
    /// </summary>
    /// <returns></returns>
    private decimal calculateServicesSubscaleScore() {
        decimal subScaleScore = 0;

        try {
            // look at rbl value field (convert to int)
            int q9 = Convert.ToInt32(rblQ9.SelectedItem.Text);
            int q10 = Convert.ToInt32(rblQ10.SelectedItem.Text);
            int q11 = Convert.ToInt32(rblQ11.SelectedItem.Text);
            int q12 = Convert.ToInt32(rblQ12.SelectedItem.Text);

            subScaleScore = (Convert.ToDecimal(q9 + q10 + q11 + q12) / Convert.ToDecimal(4));
            subScaleScore = Math.Round(subScaleScore, 2);

        } catch (Exception ex) {
            Exception _tbilogerror = HandleTBIException(ex, "QUESTInstrument.aspx", "100027", "calculateServicesSubscaleScore()");
        }

        return subScaleScore;
    }

    /// <summary>
    /// For items 1 to 12, add the ratings of the valid responses and divide this sum by the number of valid items
    /// </summary>
    /// <returns></returns>
    private decimal calculateTotalQUESTScore() {
        decimal totalScore = 0;

        try {
            // look at rbl value field (convert to int)
            int q1 = Convert.ToInt32(rblQ1.SelectedItem.Text);
            int q2 = Convert.ToInt32(rblQ2.SelectedItem.Text);
            int q3 = Convert.ToInt32(rblQ3.SelectedItem.Text);
            int q4 = Convert.ToInt32(rblQ4.SelectedItem.Text);
            int q5 = Convert.ToInt32(rblQ5.SelectedItem.Text);
            int q6 = Convert.ToInt32(rblQ6.SelectedItem.Text);
            int q7 = Convert.ToInt32(rblQ7.SelectedItem.Text);
            int q8 = Convert.ToInt32(rblQ8.SelectedItem.Text);
            int q9 = Convert.ToInt32(rblQ9.SelectedItem.Text);
            int q10 = Convert.ToInt32(rblQ10.SelectedItem.Text);
            int q11 = Convert.ToInt32(rblQ11.SelectedItem.Text);
            int q12 = Convert.ToInt32(rblQ12.SelectedItem.Text);

            totalScore = (Convert.ToDecimal(q1 + q2 + q3 + q4 + q5 + q6 + q7 + q8 + q9 + q10 + q11 + q12) / Convert.ToDecimal(12));
            totalScore = Math.Round(totalScore, 2);

        } catch (Exception ex) {
            Exception _tbilogerror = HandleTBIException(ex, "QUESTInstrument.aspx", "100027", "calculateTotalQUESTScore()");
        }

        return totalScore;
    }

    #endregion
}